<?php
/**
 * @category    Pinpoint
 * @package     Pinpoint_TopLevelCategory
 * @copyright   Copyright (c) 2017 Pinpoint Designs. (http://www.pinpointdesigns.co.uk)
 * @author      Douglas Radburn <douglas.radburn@pinpointdesigns.co.uk>
 */

namespace Pinpoint\TopLevelCategory\Block;

use Magento\Catalog\Model\ResourceModel\Category\CollectionFactory as CategoryCollection;
use Magento\Framework\Registry;

class TopLevelCategory extends \Magento\Framework\View\Element\Template
{

    /**
     * @var \Magento\Catalog\Model\ResourceModel\Category\CollectionFactory
     */
    protected $_categoryCollectionFactory;

    /**
     * @var \Magento\Framework\Registry
     */
    protected $_coreRegistry;

    const DEFAULT_CATEGORY  = 2;

    public function __construct(
        \Magento\Framework\View\Element\Template\Context $context,
        CategoryCollection $categoryCollectionFactory,
        Registry $coreRegistry,
        array $data = []
    )
    {
        $this->_categoryCollectionFactory = $categoryCollectionFactory;
        $this->_coreRegistry = $coreRegistry;
        parent::__construct($context, $data);
        $this->setTemplate('Pinpoint_TopLevelCategory::catalog/toplevelcategory.phtml');
    }

    /**
     * Get all categories for a specified category
     * for display on a top level category page
     *
     * This function allows for a category to be passed via xml (category_id)
     * alternatively, it gets the current catgeory and tries to lookup based on that
     * As a fallback, it will use the DEFAULT CATEGORY set as a constant incase
     * you try to use this on a page that isn't a category and don't pass an ID
     *
     * @param bool $excludeViewAll
     * @return Magento\Catalog\Model\ResourceModel\Category\CollectionFactory $_category
     */
    public function getCategories($excludeViewAll = false)
    {

        $categoryId = self::DEFAULT_CATEGORY;

        if($this->getCategoryId() != '') {
            $categoryId = $this->getCategoryId();
        } elseif ($this->getCategory() != null) {
            $categoryId = $this->getCategory()->getId();
        }

        $_categoryCollection = $this->_categoryCollectionFactory
            ->create()
            ->addAttributeToFilter('parent_id', ['eq' => $categoryId])
            ->addAttributeToSelect('*')
            ->addUrlRewriteToResult()
            ->addIsActiveFilter()
            ->addAttributeToSort('position')
            ->setStoreId(0)
            ->load()
        ;

        if($excludeViewAll === true) {
            $_categoryCollection->addAttributeToFilter('name', ['nlike' => 'View All%']);
        }

        return $_categoryCollection->getItems();

    }

    /**
     *
     *
     * @return mixed|null
     */
    public function getCategory()
    {
        return $this->_coreRegistry->registry('current_category');
    }

}
